class TOKEN:
    """Constants token for air2phin."""

    QUESTION: str = "?"
    COMMA: str = ","
    POINT: str = "."
    SPACE: str = " "
    ZERO: str = "0"
    IMPORT: str = "import"
    STRING: str = "str"
    CODE: str = "code"
    NEW_LINE: str = "\n"


class KEYWORD:
    """Constants keywords for air2phin."""

    MIGRATE_MARK: str = "-air2phin"
    WORKFLOW_SUBMIT: str = "submit"
    AIRFLOW_DAG_SCHEDULE: str = "schedule_interval"
    AIRFLOW_DAG: str = "airflow.DAG"
    AIRFLOW_DAG_SIMPLE: str = "DAG"
    DEFAULT_SCHEDULE: str = "0 0 0 * * ? *"


class REGEXP:
    """Constants regular expression for air2phin."""

    PATH_YAML: str = "*.yaml"
    PATH_PYTHON: str = "*.py"
    PATH_ALL: str = "**/*"


class CONFIG:
    """Constants config file for air2phin."""

    NAME: str = "name"

    EXAMPLE: str = "examples"

    MIGRATION: str = "migration"
    MODULE: str = "module"
    PARAMETER: str = "parameter"

    ACTION: str = "action"
    SOURCE: str = "src"
    DESTINATION: str = "dest"

    KW_REPLACE: str = "replace"
    KW_ADD: str = "add"
    KW_REMOVE: str = "remove"

    ARGUMENT: str = "arg"
    DEFAULT: str = "default"
    TYPE: str = "type"
    VALUE: str = "value"


class NUMBER:
    """Constants number for air2phin."""

    SCHEDULE_TOTAL_NUM: int = 9
    SCHEDULE_SPACE_NUM: int = 4



from air2phin.fake.core.connection import Connection
from air2phin.fake.core.hook import BaseHook

try:
    import MySQLdb
except ImportError:
    raise ImportError("This MySQLdb module does not seem to be installed.")


class MySqlHook(BaseHook):
    """Interact with MySQL.

    This hook is a fake hook for Airflow MySQL hook, to allow user do not change their code but use
    dolphinscheduler datasource connection to connect to MySQL database.

    :param connection: specific hook connection. :class:``air2phin.fake.core.connection.Connection`` object.
    """

    def __init__(self, connection: Connection, *args, **kwargs):
        super().__init__(connection)

    def get_conn(self) -> "MySQLdb.connections.Connection":
        """Get MySQL connection object."""
        conn_args = dict(
            host=self.connection.host,
            port=self.connection.port,
            db=self.connection.schema,
            user=self.connection.login,
            passwd=self.connection.password,
        )
        return MySQLdb.connect(**conn_args)



from typing import NamedTuple


class Connection(NamedTuple):
    """Connection Info store in dolphinscheduler metadata database."""

    host: str
    port: int
    schema: str
    login: str
    password: str



from air2phin.constants import KEYWORD, NUMBER, TOKEN


def convert_schedule(val: str) -> str:
    """Convert airflow schedule string to dolphinscheduler's.

    Will convert including:
    * crontab schedule string from ``5 4 * * *`` to ```0 5 4 * * ? *``
    * shortcut schedule string like ``@daily`` to ``0 0 0 * * ? *``.
    """
    if (
        len(val) == NUMBER.SCHEDULE_TOTAL_NUM
        and val.count(TOKEN.SPACE) == NUMBER.SCHEDULE_SPACE_NUM
    ):
        val_list = val.split(TOKEN.SPACE)
        val_list.insert(0, TOKEN.ZERO)
        val_list.insert(-1, TOKEN.QUESTION)
        return TOKEN.SPACE.join(val_list)
    return KEYWORD.DEFAULT_SCHEDULE
